//
// C++ Interface: errorcodes
//
// Description: 
//
//
// Author: Lorenzo Bettini <http://www.lorenzobettini.it>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef ERRORCODES_H
#define ERRORCODES_H

#define NOT_ENOUGH_MEMORY 1
#define REQ_LONG_OPTION 2
#define REQ_SHORT_OPTION 3
#define FOUND_BUG 4
#define GROUP_UNDEFINED 5
#define INVALID_DEFAULT_VALUE 6
#define NOT_REQUESTED_TYPE 7
#define NOT_VALID_SPECIFICATION 8
#define SPECIFY_FLAG_STAT 9
#define NOT_GROUP_OPTION 10
#define SPECIFY_GROUP 11
#define INVALID_NUMERIC_VALUE 12
#define INVALID_ENUM_TYPE_USE 13
#define MODE_UNDEFINED 14
#define NOT_MODE_OPTION 15
#define SPECIFY_MODE 16
#define HELP_REDEFINED 17
#define VERSION_REDEFINED 18

#endif
